#ifndef NT2_INCLUDE_FUNCTIONS_DIVIDES_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_DIVIDES_HPP_INCLUDED

#include <nt2/operator/include/functions/divides.hpp>

#endif
